<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fur" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Siere (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Strenç</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Vierç</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Mole la Atenzion</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln peraule</numerusform>
            <numerusform>%Ln peraulis</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minût</numerusform>
            <numerusform>%Ln minûts</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%L1% of %Ln minût</numerusform>
            <numerusform>%L1% of %Ln minûts</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation>
            <numerusform>%L1% of %Ln peraule</numerusform>
            <numerusform>%L1% of %Ln peraulis</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Progrès in zornade</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Striche Plui Lungje</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Striche Curint</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n zornade</numerusform>
            <numerusform>%n zornadis</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation>%L1% dal progrès di zornade</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Selezione la lenghe</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Cence Titul %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (Dome-Leture)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Mi displâs</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>No pues salvâ &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Salve il file come</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Impussibil scrivi par sore &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Cambie il non</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Impussibil cambiâ in non &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Tornâ a cjariâ il file?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Ricjariâ il file &quot;%1&quot; dal disc?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Ducj i cambiaments a vignaran pierdûts.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Ricjarie</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Cence Titul &amp;1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Domande</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Salvant in test plan si pierdaran dutis lis formatazions. Lassâ stâ la formatazion?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>File Cambiât</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>Il file &apos;%1&apos; al è stât cambiât di un altri program.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Âstu voie di ricjariâ il file?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Ricjarie</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Lasse pierdi</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>File Cancelât</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>Il file %1 al è stât cancelât di un altri program.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Âstu voie di salvâ o sierâ il file?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Impussibil vierzi l&apos;archivi.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Cîr:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Cambie cun:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Lasse pierdi il câs</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Dome peraulis interiis</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Espression regolâr</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Cîr par sù</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Cîr par jù</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>Cîr</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>Rimplace</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Rimplace Dut</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Cîr</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Rimplace</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Rimplaçâ %n istance?</numerusform>
            <numerusform>Rimplaçâ %n istancis?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Domande</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Mi displâs</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Frase no cjatade.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>OpenDocument Test</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Rich Text Format</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Test plan</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Ducj i files</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Ducj i files sopuartâts</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>OpenDocument Flat XML</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Zonte</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Controle Spelling...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Nissun sugjeriment cjatât)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Vierç Imagjine</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Imagjinis</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selezione la lenghe de aplicazion:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Language&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Notis</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Par plasè stude e torne impie la aplicazion parcè che il cambiament de lenghe al vedi efiet.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Impussibil vierzi l&apos;archivi.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Preferencis</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Gjenerâl</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistichis</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Toolbar</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Controle la ortografie</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Selezione dizionari</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Mi displâs</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Impussibil vierzi l&apos;archivi.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>L&apos;archivi nol à dentri un dizionari che si pues doprâ.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Domande</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Scurtadoriis</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Une o plui scurtadoriis a son in conflit. Vadio indenant istes?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Il dizionari &quot;%1&quot; al esist za. Âstu voie di rimplaçâlu?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Obietîf di zornade</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nuie</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Minûts:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Peraulis:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Editing</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Za centrât in verticâl</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Block insertion cursor</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Fonts Lissis</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Suns de machine di scrivi</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Smart quotes:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Dopli</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Singul</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Senis</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Divisôr:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>O stoi salvant</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Visiti la posizion dal cursôr</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Contegjo Peraulis</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Contegjo Pagjinis</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Contegjo Paragrafis</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Contegjo caratars</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Caratars:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Paragrafis:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Algoritmi pal contegjo des peraulis</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Resetâ il progrès de zornade a zero?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Scrivi byte order mark intai file di test plan</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Formât di default:</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Resete Vuê</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Storie</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Visiti de storie</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Mostre Strichis</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Minim progrès des strichis:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Viôt limits des peraulis</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Divît i caratars par sîs</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Conte ogni letare come une peraule</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Algoritmi pal contegjo des pagjinis</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stîl</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Dome Iconis</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Dome Test</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Test Dongje Iconis</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Test Sot Iconis</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Posizion Test:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Azions</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Môf sù</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Môf jù</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Zonte Separatôr</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Comant</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Scurtadorie</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Azion</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Check spelling as you type</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Lasse lis peraulis MAIUSCULIS</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Lasse lis peraulis cun numars</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Lenghe</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Zonte</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Gjave</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Dizionari Personâl</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Gjavâ il dizionari curint?</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Interface dal Utilizadôr</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Mostre simpri lis scrollbars</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Mostre simpri la bare sore</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Mostre simpri la bare sot</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>File RTF no supuartât</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Cence savê rivâts ae fin dal file.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Môf senis in sù</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Up</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Alterne la liste des senis</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Mostre la liste des senis (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Plate la liste des senis (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtri</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Môf senis in jù</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Ridimensione la liste des senis</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Default</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Gjestis Sessions</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>Sessions</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Gnûf</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Dupliche</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Rinomine</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Cancele</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Cambie Cun</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Gnove Session</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Dupliche Session</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Rinomine Session</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Domande</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Cancelâ la session selezionade?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Non de Session:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Mi displâs</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>La session cun chest non je za doprade.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>Gnûf...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>Gjestis...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Nete</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Resete cun Default</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Scurtadorie:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Replacing quotation marks...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Par plasè spiete</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Controle Ortografie</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>Zonte</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>Lasse</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>Lasse Dut</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>Cambie</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>Cambie Dut</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Nol è intal dizionari:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Cambie cun:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>O stoi controlant l&apos;ortografie...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancele</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Par plasè spiete</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Continuâ il control da l&apos;inizi dal file?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Control Ortografie finît.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Simbui</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Simbui doprâts di resint</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Ducj i Simbui</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detais</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Non:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Inserìs</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Blocs</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Scripts</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Cence Titul %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Non:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Cence Imagjine</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>A Tocs</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Centrât</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Stirât</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Scalât</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Zoomât</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Trasparence:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Posizion:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Largjece:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Round Text Background Corners</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Ragjo:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Blur Text Background</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Text Background Drop Shadow</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Spostament Verticâl:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Margjins</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Barcon:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Pagjine:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Sposte in dentri la prime linie</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Par sore:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Sot:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Gjave</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Edite Teme</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Fondâl dal Barcon</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Colôr:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Imagjine:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation>pixels</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Çampe</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Colôr Fondâl dal Test</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Diestre</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Font:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Pierdût:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Spaziature Liniis</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Singul</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1.5 Liniis</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Dopli</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Proporzionâl</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Altece:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Spaziadure Paragraf</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Largjece Tab:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Gnûf Temi</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Temis</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Default</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Gentle Blues</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Old School</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Space Dreams</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Writing Desk</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Gnûf</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Dupliche</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Personalize</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edite</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Cancele</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Impuarte</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Espuarte</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Domande</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Cancelâ temi &quot;%1&quot;?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Temis (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Impuarte Teme</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Espuarte Teme</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Bitter Skies</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Enchantment</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Spy Games</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Tranquility</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Domande</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Cancelâ il Timer?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Words:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Pages:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Met il Ritart</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Met il Timp</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Ritart:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Timp:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Memo:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edite</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Cancele</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Nissun Timers al va</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Timers</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Gnûf</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Resint</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Domande</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Cancelâ i Timers di Editing?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>O stoi cjariant i temis</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>O stoi cjariant i suns</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Cence Titul</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Vierç File</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>Su FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Un sempliç word processor a plen schermi</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publicât sot la licenze &lt;a href=%1&gt;GPL 3&lt;/a&gt; </translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Caratars: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Pagjinis: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Paragrapis: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Peraulis: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Vierzidure %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Cence Titul %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Liste ducj i documents</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Cambie in tal prossim document</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Cambie intal document di prime</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Cambie intal prin document</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Cambie intal ultin document</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Cambie intal document %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>O stoi cjariant i setagjios</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Emergency cache is not writable.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Ocjo</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter nol è stât sierât par ben.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Restore from the emergency cache?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Cualchi files nol pues jessi viert.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Cualchi files al vignarà viert dome in leture.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; is newer than the cached copy.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Overwrite newer file?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Salvâ i cambiaments?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Salvâ i cambiaments dal file &quot;%1&quot; prin di sierà?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>I cambiaments a vignaran pierdûts se no tu ju salvis.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Impussibil cjariâ i suns de machine di scrivi.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>File</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Gnûf</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>Vierç...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Ricjarie</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>Salve</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Salve cun non...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>Rinomine...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Salve Dut</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Remene Sessions</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Gnove Session</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>Stampe...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Siere</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Va Fûr</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>Edite</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>Indaûr</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>Indenant</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Taie</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Cupie</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>Incole</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Incole Cence Formât</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Selezione Dut</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Selezione Senis</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>Formât</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>Gruessut</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>Italic</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>Sotlineât</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>Sbarât</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>Superscript</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>Subscript</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>Met viers çampe</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>Met centrât</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Met viers diestre</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>Met in rie e giustifiche</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>Scurte Identazion</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>Aumente Identazion</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Le&amp;ft to Right Block</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Ri&amp;ght to Left Block</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>Imprescj</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>Cjate...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Cjate Indenant</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Cjate Indaûr</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>Rimplace...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>Smart Quotes</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Inzorne Document</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Inzorne Selezion</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>Spelling...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Met Lenghe</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>Timers...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>Simbui...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>Progres de Zornade</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Mostre Toolbar</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Mostre Iconis dal Menu</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>Test Focalizât</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>Plen Schermi</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>Minimize</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>Temis...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>Preferencis...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Focus Off</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Focus Une Rie</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Focus Trê Riis</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>Paragrafi</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Focus Paragrafi</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Jutori</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Lenghe de Applicazion...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Cualchi files nol è supuartât e nol vignarà viert.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>Off</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>Une Rie</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>Trê Riis</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Informazions</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Informazions su QT</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>Setup Pagjine...</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>Intestazion</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Intestazion &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Intestazion &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Intestazion &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Intestazion &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Intestazion &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Intestazion &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>Normâl</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Inzorne Document Smart Quotes</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Inzorne Selezion Smart Quotes</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
